pub const ONE_WEAPON: i32 = 1;
pub const ONE_SCRAP: i32 = ONE_WEAPON * 2;
pub const ONE_REC: i32 = ONE_SCRAP * 3;
pub const ONE_REF: i32 = ONE_REC * 3;

pub const KEY_SYMBOL: &str = "key";
pub const KEYS_SYMBOL: &str = "keys";
pub const METAL_SYMBOL: &str = "ref";
pub const EMPTY_SYMBOL: &str = "nothing";